"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RBBuilder = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactBootstrap = require("react-bootstrap");

var _FieldCommon = require("./FieldCommon");

var _Field = require("./Field");

var _FieldArray = require("./FieldArray");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var createSubmitSpinner = () => /*#__PURE__*/_react.default.createElement(_reactBootstrap.Spinner, {
  className: "ml-2 align-middle",
  animation: "border",
  variant: "primary",
  role: "status"
}, /*#__PURE__*/_react.default.createElement("span", {
  className: "sr-only"
}, "Waiting for response"));

var createSubmit = (sendText, _ref) => {
  var _ref2;

  var {
    isLoadingSubmit,
    errorSubmit,
    successSubmit,
    didSubmbit,
    isValid,
    validationErrorText
  } = _ref;
  return /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement(_reactBootstrap.Button, {
    disabled: isLoadingSubmit,
    variant: "primary",
    type: "submit"
  }, sendText), isLoadingSubmit && createSubmitSpinner(), !errorSubmit && !successSubmit && didSubmbit && !isValid ? /*#__PURE__*/_react.default.createElement("span", {
    className: "ml-2 rbf-text-red",
    role: "status"
  }, validationErrorText) : !isLoadingSubmit ? (_ref2 = errorSubmit && /*#__PURE__*/_react.default.createElement("span", {
    className: "ml-2 rbf-text-red",
    role: "status"
  }, errorSubmit)) !== null && _ref2 !== void 0 ? _ref2 : successSubmit && /*#__PURE__*/_react.default.createElement("span", {
    className: "ml-2 rbf-text-green",
    role: "status"
  }, successSubmit) : null);
};

var getSubmit = (customSubmit, props) => {
  if (customSubmit) {
    if (typeof customSubmit === 'string') {
      return createSubmit(customSubmit, props);
    }

    var {
      isLoadingSubmit,
      successSubmit,
      errorSubmit
    } = props;
    return customSubmit(isLoadingSubmit, successSubmit, errorSubmit);
  }

  return createSubmit('Send', props);
};

var RBBuilder = (_ref3) => {
  var {
    form: {
      validateForm,
      handleSubmit,
      values,
      setFieldValue: handleChange,
      errors,
      setErrors,
      submitCount,
      isValid
    },
    validationSchema,
    initialValues,
    customSubmit,
    isLoadingSubmit,
    errorSubmit,
    fieldErrorSubmit,
    successSubmit,
    validationErrorText = 'Error',
    children
  } = _ref3;
  var didSubmbit = submitCount > 0;
  (0, _react.useEffect)(() => {
    if (didSubmbit) {
      validateForm();
    }
  }, [didSubmbit, validateForm, validationSchema]);
  (0, _react.useEffect)(() => {
    if (fieldErrorSubmit) {
      setErrors(fieldErrorSubmit);
    }
  });
  return /*#__PURE__*/_react.default.createElement(_reactBootstrap.Form, {
    noValidate: true,
    onSubmit: handleSubmit
  }, (0, _FieldCommon.RBFormObjectRecursiveAssignProps)(children, (_ref4) => {
    var {
      type,
      props
    } = _ref4;
    var typeComponent = props.customInput ? 'custom' : type;

    switch (typeComponent) {
      case _Field.RBField:
        return (0, _FieldCommon.RBFieldAssignProps)(_objectSpread(_objectSpread({}, props), {}, {
          values,
          errors,
          didSubmbit,
          handleChange
        }), false);

      case _FieldArray.RBFieldArray:
        return (0, _FieldCommon.RBArrayAssignProps)(_objectSpread(_objectSpread({}, props), {}, {
          values,
          errors,
          didSubmbit,
          handleChange,
          initialValues
        }), false);

      case 'custom':
        return (0, _FieldCommon.RBCustomAssignProps)(_objectSpread(_objectSpread({}, props), {}, {
          values,
          errors,
          didSubmbit,
          handleChange
        }), false);

      default:
        return;
    }
  }), getSubmit(customSubmit, {
    isLoadingSubmit,
    errorSubmit,
    successSubmit,
    didSubmbit,
    isValid,
    validationErrorText
  }));
};

exports.RBBuilder = RBBuilder;