"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getLayout = exports.getSizeClass = exports.createContentLabel = exports.createLabel = exports.getSectionLabel = exports.getBreakpoints = exports.getIdLabel = exports.RBArrayAssignProps = exports.RBCustomAssignProps = exports.RBFieldAssignProps = exports.RBFormObjectRecursiveAssignProps = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactBootstrap = require("react-bootstrap");

var _Utils = require("./Utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var getValidation = (didSubmbit, error) => {
  var validation = {
    isValid: false,
    isInvalid: false
  };

  if (didSubmbit) {
    validation.isValid = !error;
    validation.isInvalid = error;
  }

  return validation;
};

var RBFormObjectRecursiveAssignProps = (children, fn) => _react.default.Children.map(children, child => {
  if (! /*#__PURE__*/_react.default.isValidElement(child)) {
    return child;
  }

  var propsSource = _objectSpread({}, fn(child));

  var {
    children
  } = child.props;

  if (children) {
    propsSource.children = RBFormObjectRecursiveAssignProps(children, fn);
  }

  return /*#__PURE__*/_react.default.cloneElement(child, propsSource);
});

exports.RBFormObjectRecursiveAssignProps = RBFormObjectRecursiveAssignProps;

var RBArrayItemAssignProps = (_ref) => {
  var {
    nameArray,
    indexValue,
    name,
    values,
    errors
  } = _ref;
  return {
    name: "".concat(nameArray, ".").concat(indexValue, ".").concat(name),
    value: values[indexValue][name],
    error: errors && errors[indexValue] && errors[indexValue][name]
  };
};

var RBFieldAssignProps = (props, isFromArray) => {
  var propsSource = {};

  var {
    didSubmbit,
    handleChange
  } = props,
      rest = _objectWithoutProperties(props, ["didSubmbit", "handleChange"]);

  if (isFromArray) {
    var propsInner = RBArrayItemAssignProps(props);
    propsSource = _objectSpread({}, propsInner);
  } else {
    var {
      name,
      values,
      errors
    } = rest;
    propsSource.nameValue = name;
    propsSource.value = values[name];
    propsSource.error = errors && errors[name];
  }

  var {
    isValid,
    isInvalid
  } = getValidation(didSubmbit, propsSource.error);
  propsSource.isValid = isValid;
  propsSource.isInvalid = isInvalid;
  propsSource.handleChange = handleChange;
  return propsSource;
};

exports.RBFieldAssignProps = RBFieldAssignProps;

var RBCustomAssignProps = (props, isFromArray) => {
  var propsSource = RBFieldAssignProps(props, isFromArray);
  var {
    name,
    nameValue,
    handleChange
  } = propsSource;

  propsSource.onChange = value => {
    handleChange(isFromArray ? name : nameValue, value);
  };

  return propsSource;
};

exports.RBCustomAssignProps = RBCustomAssignProps;

var RBArrayAssignProps = (props, isFromArray) => {
  var propsSource = {};

  var {
    name,
    didSubmbit,
    handleChange,
    initialValues
  } = props,
      rest = _objectWithoutProperties(props, ["name", "didSubmbit", "handleChange", "initialValues"]);

  if (isFromArray) {
    var propsInner = RBArrayItemAssignProps(props);
    propsSource = {
      name: propsInner.name,
      values: propsInner.value,
      errors: propsInner.error
    };
  } else {
    var {
      values,
      errors
    } = rest;
    propsSource.nameValue = name;
    propsSource.values = values[name];
    propsSource.errors = errors && errors[name];
  }

  propsSource.didSubmbit = didSubmbit;
  propsSource.handleChange = handleChange;
  propsSource.initialValues = (0, _Utils.isArray)(initialValues[name]) ? initialValues[name][0] : initialValues[name];
  return propsSource;
};

exports.RBArrayAssignProps = RBArrayAssignProps;

var getIdLabel = name => "rbf_".concat(name, "_label");

exports.getIdLabel = getIdLabel;

var getBreakpoints = function getBreakpoints(props) {
  var key = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  var {
    ["xs".concat(key)]: xs,
    ["sm".concat(key)]: sm,
    ["md".concat(key)]: md,
    ["lg".concat(key)]: lg,
    ["xl".concat(key)]: xl
  } = props;
  var breakpoints = {
    xs,
    sm,
    md,
    lg,
    xl
  };
  return Object.fromEntries(Object.entries(breakpoints).filter((_ref2) => {
    var [_, value] = _ref2;
    return value != null;
  }));
};

exports.getBreakpoints = getBreakpoints;

var getSectionLabel = (_ref3) => {
  var {
    name,
    as,
    size,
    className
  } = _ref3,
      rest = _objectWithoutProperties(_ref3, ["name", "as", "size", "className"]);

  var propsLabel = {};
  var propsLabelClassNames = [];

  if (name) {
    propsLabel.id = getIdLabel(name);
  }

  if (className) {
    propsLabelClassNames.push(className);
  }

  if (as && as.displayName == _reactBootstrap.Row.displayName) {
    propsLabel = _objectSpread(_objectSpread({}, propsLabel), {}, {
      column: size !== null && size !== void 0 ? size : true
    }, getBreakpoints(rest, 'Label'));
  } else {
    propsLabelClassNames.push(getSizeClass(size));
  }

  if (propsLabelClassNames.length > 0) {
    propsLabel.className = propsLabelClassNames.join(' ');
  }

  return createLabel(_reactBootstrap.Form.Label, propsLabel, rest);
};

exports.getSectionLabel = getSectionLabel;

var createLabel = (component, propsLabel, props, label) => {
  var Label = component;
  return /*#__PURE__*/_react.default.createElement(Label, propsLabel, label !== null && label !== void 0 ? label : createContentLabel(props));
};

exports.createLabel = createLabel;

var createContentLabel = (_ref4) => {
  var {
    label,
    required
  } = _ref4;
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, label, required && /*#__PURE__*/_react.default.createElement("span", {
    className: "ml-1 rbf-text-red"
  }, "*"));
};

exports.createContentLabel = createContentLabel;

var getSizeClass = function getSizeClass(size) {
  var isLabel = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  var prefix = isLabel ? 'label' : 'height';

  if (size) {
    if (size === 'sm') {
      return "rbf-".concat(prefix, "-sm");
    } else if (size === 'lg') {
      return "rbf-".concat(prefix, "-lg");
    }
  }

  if (!isLabel) {
    return "rbf-".concat(prefix);
  }
};

exports.getSizeClass = getSizeClass;

var getLayout = (propsGroup, Label, Content, props) => {
  var {
    as
  } = props;
  var Field;

  if (as && as.displayName == _reactBootstrap.Row.displayName) {
    var propsCol;
    var breakpointsControl = getBreakpoints(props, 'Control');

    if (Label) {
      propsCol = breakpointsControl;
    } else {
      var breakpointsLabel = getBreakpoints(props, 'Label');
      propsCol = {
        xs: {
          span: breakpointsControl.xs,
          offset: breakpointsLabel.xs
        },
        sm: {
          span: breakpointsControl.sm,
          offset: breakpointsLabel.sm
        },
        md: {
          span: breakpointsControl.md,
          offset: breakpointsLabel.md
        },
        lg: {
          span: breakpointsControl.lg,
          offset: breakpointsLabel.lg
        },
        xl: {
          span: breakpointsControl.xl,
          offset: breakpointsLabel.xl
        }
      };
    }

    Field = /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, Label, /*#__PURE__*/_react.default.createElement(_reactBootstrap.Col, propsCol, Content));
  } else {
    if (as && as.displayName == _reactBootstrap.Col.displayName) {
      propsGroup = _objectSpread(_objectSpread({}, propsGroup), getBreakpoints(props));
    }

    Field = /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, Label, Content);
  }

  return /*#__PURE__*/_react.default.createElement(_reactBootstrap.Form.Group, propsGroup, Field);
};

exports.getLayout = getLayout;