"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RBForm = void 0;

var _react = _interopRequireWildcard(require("react"));

var _formik = require("formik");

var _Setup = require("./Setup");

var _Builder = require("./Builder");

var _Validation = require("./Validation");

var _Utils = require("./Utils");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var filterEditable = (target, source) => {
  if ((0, _Utils.isObject)(target) && (0, _Utils.isObject)(source)) {
    target = _objectSpread({}, target);

    var _loop = function _loop(key) {
      if (source[key] === true) {
        // True means that key must be hidden, otherwise this is undefined.
        delete target[key];
      } else if ((0, _Utils.isObject)(target[key])) {
        target[key] = filterEditable(target[key], source[key]);
      } else if ((0, _Utils.isArray)(target[key]) && Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = target[key].map(value => filterEditable(value, source[key]));
      }
    };

    for (var key in source) {
      _loop(key);
    }
  }

  return target;
};

var initialStateForm = {
  didLoad: false,
  validationSchema: null,
  valuesHidden: null,
  initialValues: null,
  values: null,
  isLoadingSubmit: false,
  successSubmit: false,
  errorSubmit: null,
  fieldErrorSubmit: null
};

var reducerForm = (state, action) => {
  switch (action.type) {
    case 'update':
      {
        var _action$payload = action.payload,
            {
          validationShape,
          values,
          didChangeInitialValues
        } = _action$payload,
            rest = _objectWithoutProperties(_action$payload, ["validationShape", "values", "didChangeInitialValues"]);

        var stateNew = _objectSpread({
          didLoad: true,
          validationSchema: (0, _Validation.getShapeObject)(validationShape)
        }, rest);

        if (didChangeInitialValues) {
          stateNew.values = values;
        }

        return _objectSpread(_objectSpread({}, state), stateNew);
      }

    case 'startSubmit':
      {
        return _objectSpread(_objectSpread({}, state), {}, {
          isLoadingSubmit: true
        });
      }

    case 'submitSuccess':
      {
        var response = action.payload;
        return _objectSpread(_objectSpread({}, state), {}, {
          isLoadingSubmit: false,
          successSubmit: response,
          errorSubmit: null,
          fieldErrorSubmit: null
        });
      }

    case 'submitFailure':
      {
        var error = action.payload;
        var _stateNew = {
          isLoadingSubmit: false,
          successSubmit: false
        };

        if (error) {
          var {
            server: serverError,
            field: fieldErrors
          } = action.payload;

          if (fieldErrors) {
            _stateNew.fieldErrorSubmit = fieldErrors;
          }

          _stateNew.errorSubmit = serverError !== null && serverError !== void 0 ? serverError : 'Error';
        } else {
          _stateNew.errorSubmit = 'Error';
        }

        return _objectSpread(_objectSpread({}, state), _stateNew);
      }

    default:
      break;
  }
};

var RBForm = (_ref) => {
  var {
    initialValues: initialValuesForm = false,
    validationErrorText,
    customSubmit,
    onSubmit,
    children
  } = _ref;
  var initialValuesFormPrevious = (0, _Utils.usePrevious)(initialValuesForm);
  var [state, dispatch] = (0, _react.useReducer)(reducerForm, initialStateForm);
  (0, _react.useEffect)(() => {
    var validationShape = {};
    var valuesHidden = {};
    var initialValues = {};
    var values = {};
    (0, _Setup.RBFormObjectRecursiveForEach)(validationShape, valuesHidden, initialValues, (0, _Utils.isObject)(initialValuesForm) ? initialValuesForm : {}, values, (0, _Utils.isArray)(children) ? children : [children]);
    dispatch({
      type: 'update',
      payload: {
        validationShape,
        valuesHidden,
        initialValues,
        values,
        didChangeInitialValues: initialValuesFormPrevious !== initialValuesForm
      }
    });
  }, [initialValuesForm, initialValuesFormPrevious, children]);

  var handleSubmit = (values, _ref2) => {
    var {
      resetForm
    } = _ref2;
    var valuesEditable = filterEditable(values, state.valuesHidden);

    if (onSubmit) {
      dispatch({
        type: 'startSubmit'
      });
      onSubmit(valuesEditable, response => {
        onSubmitSuccess(resetForm, response);
      }, error => {
        dispatch({
          type: 'submitFailure',
          payload: error
        });
      });
    } else {
      onSubmitSuccess(resetForm);
    }
  };

  var onSubmitSuccess = function onSubmitSuccess(resetForm) {
    var response = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'Success';
    resetForm();
    dispatch({
      type: 'submitSuccess',
      payload: response
    });
  };

  return state.didLoad && /*#__PURE__*/_react.default.createElement(_formik.Formik, {
    validationSchema: state.validationSchema,
    initialValues: state.values,
    onSubmit: handleSubmit,
    enableReinitialize: true
  }, form => /*#__PURE__*/_react.default.createElement(_Builder.RBBuilder, {
    form,
    validationSchema: state.validationSchema,
    initialValues: state.initialValues,
    customSubmit,
    isLoadingSubmit: state.isLoadingSubmit,
    errorSubmit: state.errorSubmit,
    fieldErrorSubmit: state.fieldErrorSubmit,
    successSubmit: state.successSubmit,
    validationErrorText
  }, children));
};

exports.RBForm = RBForm;