"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getDatetimeString = exports.getDatetimeDate = exports.getDatetimeFormat = exports.fillMissingArrayRows = exports.ensureArray = exports.createArray = exports.isArray = exports.isObject = exports.usePrevious = void 0;

var _react = require("react");

var moment;

try {
  moment = require('moment');

  require('moment/min/locales');
} catch (_) {
  moment = null;
}

var usePrevious = value => {
  var ref = (0, _react.useRef)();
  (0, _react.useEffect)(() => {
    ref.current = value;
  });
  return ref.current;
};

exports.usePrevious = usePrevious;

var isObject = value => value != null && typeof value == 'object' && !Array.isArray(value);

exports.isObject = isObject;

var isArray = value => value != null && Array.isArray(value);

exports.isArray = isArray;

var createArray = (size, value) => Array.from({
  length: size
}, () => isArray(value) ? [] : typeof value == 'object' ? {} : value);

exports.createArray = createArray;

var ensureArray = value => isArray(value) ? value : [value];

exports.ensureArray = ensureArray;

var fillMissingArrayRows = function fillMissingArrayRows(amountRows, array) {
  var value = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  var sizeRest = amountRows - array.length;

  if (sizeRest > 0) {
    array = array.concat(createArray(sizeRest, value));
  }

  return array;
};

exports.fillMissingArrayRows = fillMissingArrayRows;

var getDatetimeFormat = (dateFormat, timeFormat) => {
  var formats = [];

  if (dateFormat || dateFormat === undefined) {
    formats.push(typeof dateFormat === 'string' ? dateFormat : 'L');
  }

  if (timeFormat || timeFormat === undefined) {
    formats.push(typeof timeFormat === 'string' ? timeFormat : 'LT');
  }

  return formats.join(' ');
};

exports.getDatetimeFormat = getDatetimeFormat;

var setMomentLocale = locale => moment.locale(locale !== null && locale !== void 0 ? locale : 'en');

var getDatetimeDate = (value, format, locale) => {
  if (moment) {
    setMomentLocale(locale);

    if (typeof value === 'string') {
      // Always a string when used inside validation.
      if (isNaN(value)) {
        return moment(value, format, true).toDate();
      }

      return moment(+value).toDate();
    }

    if (typeof value === 'number') {
      return moment(value).toDate();
    }

    if (moment.isMoment(value)) {
      return value.toDate();
    }
  }

  return value;
};

exports.getDatetimeDate = getDatetimeDate;

var getDatetimeString = (value, format, locale) => {
  if (moment) {
    setMomentLocale(locale);

    if (moment.isMoment(value)) {
      return value.format(format);
    }

    if (value instanceof Date || typeof value === 'number') {
      return moment(value).format(format);
    }

    if (typeof value === 'string' && value !== '' && !isNaN(value)) {
      return moment(+value).format(format);
    }
  }

  return value;
};

exports.getDatetimeString = getDatetimeString;