"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getShapeObject = exports.getShapeArray = exports.getShape = void 0;

var YupDefault = _interopRequireWildcard(require("yup"));

var _Utils = require("./Utils");

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

var moment;

try {
  moment = require('moment');
} catch (_) {
  moment = null;
}

var getShape = (_ref) => {
  var {
    type,
    options,
    max,
    min,
    multiple,
    htmlSize,
    dateFormat,
    timeFormat,
    locale,
    disabled,
    required,
    hidden,
    validation
  } = _ref;
  var Yup;
  var yup;
  var shouldUseDefault = true;

  if (validation) {
    if (validation.constructor.name.endsWith('Schema')) {
      yup = validation;
      shouldUseDefault = false;
    } else {
      Yup = validation;
    }
  } else {
    Yup = YupDefault;
  }

  if (shouldUseDefault) {
    switch (type) {
      case 'datetime':
        {
          if (moment) {
            var format = (0, _Utils.getDatetimeFormat)(dateFormat, timeFormat);
            yup = Yup.date().transform(function (_, originalValue) {
              return (0, _Utils.getDatetimeDate)(originalValue, format, locale);
            });
            break;
          }

          yup = Yup.date();
          break;
        }

      case 'select':
        {
          if (options) {
            yup = Yup.mixed();
            break;
          }

          if (multiple || htmlSize) {
            yup = Yup.array();
            break;
          }

          yup = Yup.string();
          break;
        }

      case 'hidden':
      case 'file':
      case 'radio':
        yup = Yup.mixed();
        break;

      case 'checkbox':
      case 'switch':
        yup = Yup.bool();
        break;

      case 'number':
      case 'range':
        {
          yup = Yup.number();

          if (max != null) {
            yup = yup.max(max);
          }

          if (min != null) {
            yup = yup.min(min);
          }

          break;
        }

      case 'email':
        yup = Yup.string().email();
        break;

      case 'url':
        yup = Yup.string().url();
        break;

      default:
        // input, text, search, password, tel, color, textarea, date, month, week, datetime-local, time
        yup = Yup.string();
        break;
    }
  }

  if (!(type === 'hidden' || hidden || disabled) && required) {
    if (type === 'checkbox' || type === 'switch') {
      yup = yup.oneOf([true]);
    } else if (type === 'select' && multiple) {
      yup = yup.min(1);
    } else {
      yup = yup.required();
    }
  }

  return yup;
};

exports.getShape = getShape;

var getShapeArray = shape => YupDefault.array().of(getShapeObject(shape));

exports.getShapeArray = getShapeArray;

var getShapeObject = shape => YupDefault.object().shape(shape);

exports.getShapeObject = getShapeObject;